@@ -15,6 +15,7 @@ from numba.core.untyped_passes import (ReconstructSSA, TranslateByteCode,
                                        IRProcessing, DeadBranchPrune,
                                        PreserveIR)
 from numba.core.compiler import DefaultPassBuilder, CompilerBase, PassManager
+from numba.core.utils import PYVERSION
 
 
 _GLOBAL = 123
@@ -653,12 +654,28 @@ class TestBranchPrunePredicates(TestBranchPruneBase, SerialMixin):
                 _CONST2 = "PLACEHOLDER2"
             return _CONST2 + 4
 
-        new = self._literal_const_sample_generator(impl, {1:0, 3:20})
+        if PYVERSION in ((3, 14), ):
+            # The order of the __code__.co_consts changes with 3.14
+            new = self._literal_const_sample_generator(impl, {0:0, 2:20})
+        elif PYVERSION in ((3, 10), (3, 11), (3, 12), (3, 13)):
+            new = self._literal_const_sample_generator(impl, {1:0, 3:20})
+        else:
+            raise NotImplementedError(PYVERSION)
+
         iconst = impl.__code__.co_consts
         nconst = new.__code__.co_consts
-        self.assertEqual(iconst, (None, "PLACEHOLDER1", 3.14159,
-                                  "PLACEHOLDER2", 4))
-        self.assertEqual(nconst, (None, 0, 3.14159,  20, 4))
+
+        if PYVERSION in ((3, 14), ):
+            self.assertEqual(iconst, ("PLACEHOLDER1", 3.14159,
+                                      "PLACEHOLDER2"))
+            self.assertEqual(nconst, (0, 3.14159,  20))
+        elif PYVERSION in ((3, 10), (3, 11), (3, 12), (3, 13)):
+            self.assertEqual(iconst, (None, "PLACEHOLDER1", 3.14159,
+                                      "PLACEHOLDER2", 4))
+            self.assertEqual(nconst, (None, 0, 3.14159,  20, 4))
+        else:
+            raise NotImplementedError(PYVERSION)
+
         self.assertEqual(impl(None), 3.14159)
         self.assertEqual(new(None), 24)
 
@@ -671,7 +688,17 @@ class TestBranchPrunePredicates(TestBranchPruneBase, SerialMixin):
 
         for c_inp, prune in (self._TRUTHY, False), (self._FALSEY, True):
             for const in c_inp:
-                func = self._literal_const_sample_generator(impl, {1: const})
+
+                if PYVERSION in ((3, 14), ):
+                    # The order of the __code__.co_consts changes with 3.14
+                    func = self._literal_const_sample_generator(impl,
+                                                                {0: const})
+                elif PYVERSION in ((3, 10), (3, 11), (3, 12), (3, 13)):
+                    func = self._literal_const_sample_generator(impl,
+                                                                {1: const})
+                else:
+                    raise NotImplementedError(PYVERSION)
+
                 self.assert_prune(func, (types.NoneType('none'),), [prune],
                                   None)
 
@@ -684,7 +711,17 @@ class TestBranchPrunePredicates(TestBranchPruneBase, SerialMixin):
 
         for c_inp, prune in (self._TRUTHY, False), (self._FALSEY, True):
             for const in c_inp:
-                func = self._literal_const_sample_generator(impl, {1: const})
+
+                if PYVERSION in ((3, 14), ):
+                    # The order of the __code__.co_consts changes with 3.14
+                    func = self._literal_const_sample_generator(impl,
+                                                                {0: const})
+                elif PYVERSION in ((3, 10), (3, 11), (3, 12), (3, 13)):
+                    func = self._literal_const_sample_generator(impl,
+                                                                {1: const})
+                else:
+                    raise NotImplementedError(PYVERSION)
+
                 self.assert_prune(func, (types.NoneType('none'),), [prune],
                                   None)
 
@@ -699,7 +736,17 @@ class TestBranchPrunePredicates(TestBranchPruneBase, SerialMixin):
 
         for c_inp, prune in (self._TRUTHY, False), (self._FALSEY, True):
             for const in c_inp:
-                func = self._literal_const_sample_generator(impl, {1: const})
+
+                if PYVERSION in ((3, 14), ):
+                    # The order of the __code__.co_consts changes with 3.14
+                    func = self._literal_const_sample_generator(impl,
+                                                                {0: const})
+                elif PYVERSION in ((3, 10), (3, 11), (3, 12), (3, 13)):
+                    func = self._literal_const_sample_generator(impl,
+                                                                {1: const})
+                else:
+                    raise NotImplementedError(PYVERSION)
+
                 self.assert_prune(func, (types.NoneType('none'),), [prune],
                                   None)
 
@@ -714,7 +761,17 @@ class TestBranchPrunePredicates(TestBranchPruneBase, SerialMixin):
 
         for c_inp, prune in (self._TRUTHY, False), (self._FALSEY, True):
             for const in c_inp:
-                func = self._literal_const_sample_generator(impl, {1: const})
+
+                if PYVERSION in ((3, 14), ):
+                    # The order of the __code__.co_consts changes with 3.14
+                    func = self._literal_const_sample_generator(impl,
+                                                                {0: const})
+                elif PYVERSION in ((3, 10), (3, 11), (3, 12), (3, 13)):
+                    func = self._literal_const_sample_generator(impl,
+                                                                {1: const})
+                else:
+                    raise NotImplementedError(PYVERSION)
+
                 self.assert_prune(func, (types.NoneType('none'),), [prune],
                                   None)
 
